# Image_Precessing

Description.
The Package image_processing is used to:
    Processing:
        - Histogram matching
        - Structural similarity
        - Resize image
    Utils:
        - Plot image
        - Plot result
        - Plot histogram
        - Read image
        - Save image

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install image_processing.

```bash
pip install image_processing
```

## Author
    - Name: Robsos P Lago,
    - Email:  

## Usage
    
    ```python
    from image_processing.processing.transformation import resize_image
    files_name.my_function()
```

## License
[MIT](https://choosealicense.com/licenses/mit/)
```